@@ -187,17 +187,87 @@ class UnderscoreTestCase(unittest.TestCase):
         self.assertEqual([0,1,2], list(filter(_ < 5, [0,1,2,10,11,12])))
 
     def test_slicing(self):
-        self.assertEqual(0,       (_[0])(range(10)))
-        self.assertEqual(9,       (_[-1])(range(10)))
-        self.assertEqual([3,4,5], (_[3:])(range(6)))
-        self.assertEqual([0,1,2], (_[:3])(range(10)))
-        self.assertEqual([1,2,3], (_[1:4])(range(10)))
-        self.assertEqual([0,2,4], (_[0:6:2])(range(10)))
+        self.assertEqual(0,       (_[0])(list(range(10))))
+        self.assertEqual(9,       (_[-1])(list(range(10))))
+        self.assertEqual([3,4,5], (_[3:])(list(range(6))))
+        self.assertEqual([0,1,2], (_[:3])(list(range(10))))
+        self.assertEqual([1,2,3], (_[1:4])(list(range(10))))
+        self.assertEqual([0,2,4], (_[0:6:2])(list(range(10))))
 
     def test_slicing_multiple(self):
         self.assertEqual(0, (_[_])(range(10), 0))
         self.assertEqual(8, (_[_ * (-1)])(range(10), 2))
 
+    def test_string_converting(self):
+        self.assertEqual("(x1) => x1", str(_))
+
+        self.assertEqual("(x1) => (x1 + 2)",  str(_ + 2))
+        self.assertEqual("(x1) => (x1 - 2)",  str(_ - 2))
+        self.assertEqual("(x1) => (x1 * 2)",  str(_ * 2))
+        self.assertEqual("(x1) => (x1 / 2)",  str(_ / 2))
+        self.assertEqual("(x1) => (x1 % 2)",  str(_ % 2))
+        self.assertEqual("(x1) => (x1 ** 2)", str(_ ** 2))
+
+        self.assertEqual("(x1) => (x1 & 2)", str(_ & 2))
+        self.assertEqual("(x1) => (x1 | 2)", str(_ | 2))
+        self.assertEqual("(x1) => (x1 ^ 2)", str(_ ^ 2))
+
+        self.assertEqual("(x1) => (x1 >> 2)", str(_ >> 2))
+        self.assertEqual("(x1) => (x1 << 2)", str(_ << 2))
+
+        self.assertEqual("(x1) => (x1 < 2)",  str(_ < 2))
+        self.assertEqual("(x1) => (x1 > 2)",  str(_ > 2))
+        self.assertEqual("(x1) => (x1 <= 2)", str(_ <= 2))
+        self.assertEqual("(x1) => (x1 >= 2)", str(_ >= 2))
+        self.assertEqual("(x1) => (x1 == 2)", str(_ == 2))
+        self.assertEqual("(x1) => (x1 != 2)", str(_ != 2))
+
+    def test_rigthside_string_converting(self):
+        self.assertEqual("(x1) => (2 + x1)",  str(2 + _))
+        self.assertEqual("(x1) => (2 - x1)",  str(2 - _))
+        self.assertEqual("(x1) => (2 * x1)",  str(2 * _))
+        self.assertEqual("(x1) => (2 / x1)",  str(2 / _))
+        self.assertEqual("(x1) => (2 % x1)",  str(2 % _))
+        self.assertEqual("(x1) => (2 ** x1)", str(2 ** _))
+
+        self.assertEqual("(x1) => (2 & x1)", str(2 & _))
+        self.assertEqual("(x1) => (2 | x1)", str(2 | _))
+        self.assertEqual("(x1) => (2 ^ x1)", str(2 ^ _))
+
+        self.assertEqual("(x1) => (2 >> x1)", str(2 >> _))
+        self.assertEqual("(x1) => (2 << x1)", str(2 << _))
+
+    def test_unary_string_converting(self):
+        self.assertEqual("(x1) => (+x1)", str(+_))
+        self.assertEqual("(x1) => (-x1)", str(-_))
+        self.assertEqual("(x1) => (~x1)", str(~_))
+
+    def test_multiple_string_converting(self):
+        self.assertEqual("(x1, x2) => (x1 + x2)", str(_ + _))
+        self.assertEqual("(x1, x2) => (x1 * x2)", str(_ * _))
+        self.assertEqual("(x1, x2) => (x1 - x2)", str(_ - _))
+        self.assertEqual("(x1, x2) => (x1 / x2)", str(_ / _))
+        self.assertEqual("(x1, x2) => (x1 % x2)", str(_ % _))
+        self.assertEqual("(x1, x2) => (x1 ** x2)", str(_ ** _))
+
+        self.assertEqual("(x1, x2) => (x1 & x2)", str(_ & _))
+        self.assertEqual("(x1, x2) => (x1 | x2)", str(_ | _))
+        self.assertEqual("(x1, x2) => (x1 ^ x2)", str(_ ^ _))
+
+        self.assertEqual("(x1, x2) => (x1 >> x2)", str(_ >> _))
+        self.assertEqual("(x1, x2) => (x1 << x2)", str(_ << _))
+
+        self.assertEqual("(x1, x2) => (x1 > x2)",  str(_ > _))
+        self.assertEqual("(x1, x2) => (x1 < x2)",  str(_ < _))
+        self.assertEqual("(x1, x2) => (x1 >= x2)", str(_ >= _))
+        self.assertEqual("(x1, x2) => (x1 <= x2)", str(_ <= _))
+        self.assertEqual("(x1, x2) => (x1 == x2)", str(_ == _))
+        self.assertEqual("(x1, x2) => (x1 != x2)", str(_ != _))
+
+    def test_reverse_string_converting(self):
+        self.assertEqual("(x1, x2, x3) => ((x1 + x2) + x3)", str(_ + _ + _))
+        self.assertEqual("(x1, x2, x3) => (x1 + (x2 * x3))", str(_ + _ * _))
+
 class CompositionTestCase(unittest.TestCase):
 
     def test_composition(self):
@@ -217,7 +287,6 @@ class CompositionTestCase(unittest.TestCase):
     def test_underscore(self):
         self.assertEqual([1, 4, 9], list(map(F() << (_ ** 2) << _ + 1, range(3))))    
 
-
 class IteratorsTestCase(unittest.TestCase):
 
     def test_take(self):
@@ -399,4 +468,5 @@ class StreamTestCase(unittest.TestCase):
         self.assertEqual(6765, fib[20])
         self.assertEqual([832040,1346269,2178309,3524578,5702887], fib[30:35])
 
-
+if __name__ == '__main__':
+    unittest.main()
